AditionalRowStyle class

Constructors

AditionalRowStyle({Color color = Colors.transparent, EdgeInsets padding = const EdgeInsets.all(0)})
const

Properties

color Color
The color to paint behind the (child).
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets
see Decoration.padding.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited