color property
The color to paint behind the (child).
This property should be preferred when the background is a simple color.
Implementation
final Color color;
The color to paint behind the (child).
This property should be preferred when the background is a simple color.
final Color color;