CommonGrid class abstract

CommonGrid is an abstract base class for grid views.

It defines common properties and functionalities shared across different grid types.

Properties:

Inheritance
Implementers

Constructors

CommonGrid({Key? key, required Widget renderItem(dynamic data), double itemSize = 120.0, double minItemDimension = 120.0, double verticalSpacing = 10, double horizontalSpacing = 10, int itemsPerRow = 3, ContainerStyle itemContainerStyle = const ContainerStyle(), bool isFixed = false, bool horizontal = false, bool invertedRow = false, bool adjustGridToStyles = false, double? gridViewHeight, double gridViewWidth = double.infinity, double containerWidth = double.infinity, double? containerHeight, Widget footerWidget = const SizedBox(), ScrollPhysics? physics, ScrollController? controller})
const

Properties

adjustGridToStyles bool
final
containerHeight double?
final
containerWidth double
final
controller ScrollController?
final
footerWidget Widget
final
gridViewHeight double?
final
gridViewWidth double
final
hashCode int
The hash code for this object.
no setterinherited
horizontal bool
final
horizontalSpacing double
final
invertedRow bool
final
isFixed bool
final
itemContainerStyle ContainerStyle
final
itemSize double
final
itemsPerRow int
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minItemDimension double
final
physics ScrollPhysics?
final
renderItem Widget Function(dynamic data)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verticalSpacing double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CommonGrid>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited