ContainerStyle class

ContainerStyle defines the styling for containers used in grid views.

This class provides a way to customize the appearance of containers in the grid.

Properties:

  • decoration: The decoration to paint behind the main container. Use this for complex backgrounds like gradients or images.
  • color: The color to paint behind the child. Prefer this property for a simple solid color. Cannot be used with decoration.
  • padding: Empty space to inscribe inside the decoration. The child is placed inside this padding. This is in addition to any padding inherent in the decoration.
  • gridViewPadding: Empty space to inscribe between the main container and the grid view. This affects the layout of the grid view within the container.

Constructors

ContainerStyle({BoxDecoration? decoration, Color color = Colors.transparent, EdgeInsets padding = const EdgeInsets.all(0), EdgeInsets gridViewPadding = const EdgeInsets.all(8.0)})
const

Properties

color Color
final
decoration BoxDecoration?
final
gridViewPadding EdgeInsets
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited