FlatGridView class

Inheritance

Constructors

FlatGridView({Key? key, required Widget renderItem(dynamic data), required List data, void onNewItemAdded()?, void onPressed(int index)?, double itemSize = 120.0, double minItemDimension = 120.0, double verticalSpacing = 10, double horizontalSpacing = 10, int itemsPerRow = 3, FlatGridViewStyle style = const FlatGridViewStyle(), ContainerStyle itemContainerStyle = const ContainerStyle(), bool isFixed = false, bool horizontal = false, bool invertedRow = false, bool adjustGridToStyles = false, double? gridViewHeight, double gridViewWidth = double.infinity, double containerWidth = double.infinity, double? containerHeight, Widget footerWidget = const SizedBox(), ScrollPhysics? physics, ScrollController? controller})
FlatGridView is a widget for displaying a flat grid of items.
const

Properties

adjustGridToStyles bool
finalinherited
containerHeight double?
finalinherited
containerWidth double
finalinherited
controller ScrollController?
finalinherited
data List
final
footerWidget Widget
finalinherited
gridViewHeight double?
finalinherited
gridViewWidth double
finalinherited
hashCode int
The hash code for this object.
no setterinherited
horizontal bool
finalinherited
horizontalSpacing double
finalinherited
invertedRow bool
finalinherited
isFixed bool
finalinherited
itemContainerStyle ContainerStyle
finalinherited
itemSize double
finalinherited
itemsPerRow int
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minItemDimension double
finalinherited
onNewItemAdded → void Function()?
final
onPressed → void Function(int index)?
final
physics ScrollPhysics?
finalinherited
renderItem Widget Function(dynamic data)
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style FlatGridViewStyle
final
verticalSpacing double
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FlatGridView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited