SimpleGridViewContainerStyle class

Constructors

SimpleGridViewContainerStyle({BoxDecoration? decoration, Color color = Colors.transparent, EdgeInsets padding = const EdgeInsets.all(0), EdgeInsets gridViewPadding = const EdgeInsets.all(8.0)})
const

Properties

color Color
The color to paint behind the (child).
final
decoration BoxDecoration?
The decoration to paint behind the main container.
final
gridViewPadding EdgeInsets
Empty space to inscribe between the main container and grid view. The (child), if any, is placed inside this padding.
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets
Empty space to inscribe inside the decoration. The (child), if any, is placed inside this padding.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited