color property

Color color
final

The color to paint behind the (child).

This property should be preferred when the background is a simple color. For other cases, such as gradients or images, use the (decoration) property.

If the (decoration) is used, this property must be null. A background color may still be painted by the (decoration) even if this property is null.

Implementation

final Color color;