gridViewPadding property
Empty space to inscribe between the main container and grid view. The (child), if any, is placed inside this padding.
Implementation
final EdgeInsets gridViewPadding;
Empty space to inscribe between the main container and grid view. The (child), if any, is placed inside this padding.
final EdgeInsets gridViewPadding;