SimpleGridViewStyle class

SimpleGridViewStyle defines the styling for containers used in SimpleGridViews.

This class allows for customization of the container's appearance within a SimpleGridView.

Properties:

  • decoration: The decoration to paint behind the main container, suitable for complex backgrounds like gradients or images.
  • color: The color to paint behind the child, recommended for a simple solid color. Not to be used simultaneously with decoration.
  • padding: Empty space to inscribe inside the decoration. This padding positions the child within it, adding to any inherent padding in the decoration.
  • gridViewPadding: Space between the main container and the grid view. Influences the layout of the grid view within its container.

Constructors

SimpleGridViewStyle({BoxDecoration? decoration, Color color = Colors.transparent, EdgeInsets padding = const EdgeInsets.all(0), EdgeInsets gridViewPadding = const EdgeInsets.all(8.0)})
const

Properties

color Color
final
decoration BoxDecoration?
final
gridViewPadding EdgeInsets
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited