SectionGridViewStyle class
It allows customization of various aspects of the grid's appearance.
Properties:
- decoration: The decoration to paint behind the main container. Use the color property for a simple solid color.
- color: The color to paint behind the child. Use this property for a simple color background.
- padding: Empty space to inscribe inside the decoration. The child, if any, is placed inside this padding.
- gridViewPadding: Empty space to inscribe between the main container and the grid view.
- titlePadding: Empty space to inscribe inside the title.
- titleAlignment: The alignment of the title within its container.
- titleBackgroundColor: The background color of the title.
- titleTextStyle: The style of the title text, including font size, weight, and color.
Constructors
- SectionGridViewStyle({BoxDecoration? decoration, Color color = Colors.transparent, EdgeInsets padding = const EdgeInsets.all(0), EdgeInsets gridViewPadding = const EdgeInsets.all(8.0), EdgeInsets titlePadding = const EdgeInsets.all(8.0), TitleAlignment titleAlignment = TitleAlignment.start, Color titleBackgroundColor = Colors.transparent, TextStyle titleTextStyle = const TextStyle(fontWeight: FontWeight.normal, fontSize: 16, color: Colors.black)})
-
const
Properties
- color → Color
-
final
- decoration → BoxDecoration?
-
final
- gridViewPadding → EdgeInsets
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleAlignment → TitleAlignment
-
final
- titleBackgroundColor → Color
-
final
- titlePadding → EdgeInsets
-
final
- titleTextStyle → TextStyle
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited